Cli

Struct Cli 

pub struct Cli<R: Runtime>(/* private fields */);
Access to the CLI APIs, managed by the app once the plugin is initialized.

Implementations

Source

impl<R: Runtime> Cli<R>

pub fn matches(&self) -> Result<Matches>

Parses the arguments the current process was started with against the CLI definition configured under plugins.cli in tauri.conf.json and returns the resolved parser::Matches. Errors if the arguments do not satisfy the CLI definition.

pub fn matches_from(&self, args: Vec<String>) -> Result<Matches>

Same as Self::matches, but parses the given args instead of the current process’ arguments. Errors if args does not satisfy the CLI definition.